@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 $auth = new BasicAuthenticator(ADMINREALM, REALMERROR);
 
@@ -90,16 +91,26 @@ insert($c,text(my_("Timestamp")));
 insert($t,$ck = cell());
 insert($ck,text(my_("Action")));
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("timestamp", "action"));
+$export->saveRow();
+
 $cnt=0;
 while ($row = $result->FetchRow()) {
+	$export->addRow(NULL);
+	
     setdefault("cell",array("class"=>color_flip_flop()));
 
     insert($t,$c = cell());
     insert($c,block($result->UserTimeStamp($row["newdt"], "M d Y H:i:s")));
+    $export->addCell($row["newdt"]);
 
     insert($t,$c = cell());
     insert($c,text($row["action"]));
-
+    $export->addCell($row["action"]);
+    $export->saveRow();
+    
     if ($totcnt % MAXTABLESIZE == MAXTABLESIZE-1)
         break;
     $cnt++;
@@ -147,6 +158,12 @@ ob_end_clean();
 insert($w,block($buf));
 */
 
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("total_records", "search_criterion", "search_expression"),
+                       array($cnt, $expression, $descrip)));      
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
