@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -71,6 +71,7 @@ while($row = $result->FetchRow()) {
             $template->Merge($template->decode($rowadd["info"]));
 
             foreach($template->userfld as $arr) {
+                $tmpfield=csv_escape($arr["value"]);
                 echo FIELDS_TERMINATED_BY.$arr["value"];
             }
         }
@@ -79,4 +80,29 @@ while($row = $result->FetchRow()) {
    echo "\n";
 }
 
+// wrap any multiline string with quotes
+
+// this function only works with php 5 and above
+function csv_escape($str) {
+    $str = str_replace(array('"', ',', "\n", "\r"), array('""', ',', "\n", "\r"), $str, $count);
+    if($count) {
+        return '"' . $str . '"';
+    } else {
+        return $str;
+    }
+}
+
+/*
+// this function adds extra spaces - not ideal but is compatible with php4
+function csv_escape($str) {
+    $replaced_str = str_replace(array('"', ',', "\n", "\r"), 
+                                array('""', ', ', " \n", " \r"), $str);
+    if(strcmp($replaced_str,$str)) {
+        return '"' . $replaced_str . '"';
+    } else {
+        return $str;
+    }
+}
+*/
+
 ?>
