@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -56,7 +56,7 @@ $err=$template->is_error();
 
 $result=&$ds->ds->Execute("SELECT ipaddr.userinf, ipaddr.location, ipaddr.telno, 
                           ipaddr.descrip, ipaddr.hname, ipaddr.ipaddr AS ip,
-                          ipaddr.baseindex AS baseip
+                          ipaddr.baseindex AS baseip, ipaddr.macaddr
                         FROM ipaddr, base
                         WHERE ipaddr.baseindex=base.baseindex AND
                            base.customer=$cust
@@ -67,7 +67,8 @@ $result=&$ds->ds->Execute("SELECT ipaddr.userinf, ipaddr.location, ipaddr.telno,
 while($row = $result->FetchRow()) {
     echo inet_ntoa($row["ip"]).FIELDS_TERMINATED_BY.$row["userinf"].FIELDS_TERMINATED_BY.
         $row["location"].FIELDS_TERMINATED_BY.$row["descrip"].FIELDS_TERMINATED_BY.
-        $row["hname"].FIELDS_TERMINATED_BY.$row["telno"];
+        $row["hname"].FIELDS_TERMINATED_BY.$row["telno"].FIELDS_TERMINATED_BY.
+        $row["macaddr"];
 
     if (!$err) {
         $restmp=&$ds->ds->Execute("SELECT info, infobin
@@ -88,7 +89,6 @@ while($row = $result->FetchRow()) {
 
 // wrap any multiline string with quotes
 
-/*
 // this function only works with php 5 and above
 function csv_escape($str) {
     $str = str_replace(array('"', ',', "\n", "\r"), array('""', ',', "\n", "\r"), $str, $count);
@@ -98,17 +98,18 @@ function csv_escape($str) {
         return $str;
     }
 }
-*/
 
-// this function adds extra spaces - no ideal but is compatible with php4
+/*
+// this function adds extra spaces - not ideal but is compatible with php4
 function csv_escape($str) {
-    $replaced_str = str_replace(array('"', ',', "\n", "\r"), array('""',
-                ', ', " \n", " \r"), $str);
+    $replaced_str = str_replace(array('"', ',', "\n", "\r"), 
+                                array('""', ', ', " \n", " \r"), $str);
     if(strcmp($replaced_str,$str)) {
         return '"' . $replaced_str . '"';
     } else {
         return $str;
     }
 }
+*/
 
 ?>
