@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,9 @@ $w=myheading($p, $title);
 
 // display opening text
 insert($w,heading(3, "$title."));
-insert($w,textbrbr(my_("Export IP details data to flat ascii files.  The file will contain six columns each delimited by TAB. The first column contains the IP address, the second the user, the third the location, the fourth the description, fifth the hostname and the sixth the telephone number.")));
+insert($w,text(my_("Export IP details data to flat ascii files.  The file will contain six columns each delimited by TAB. The columns are exported in the following order: ")));
+
+insert($w,text(my_("IP address, user, location, description, hostname, telephone number and mac address.")));
 
 insert($w,block("<p>"));
 insert($w,text(my_("The user defined fields defined in the iptemplate.xml file will be appended as additional columns to the above in the order specified in the template.")));
