@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Frank Elsner [FE], June 2005
@@ -143,8 +143,8 @@ while ($data = fgetcsv ($fp, 4098, FIELDS_TERMINATED_BY)) {
       break;
    }
 
-   $ipaddr=$data[0];
-   $base=inet_aton($data[0]);
+   $ipaddr=trim($data[0]);
+   $base=inet_aton(trim($data[0]));
    $descrip=$data[1];
 
    $size=getSizeFromMask($data[2]);
