@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,7 @@ newhtml($p);
 $w=myheading($p, $title);
 
 // explicitly cast variables as security measure against SQL injection
-list($cust, $format) = myRegister("I:cust S:format");
+list($cust, $format, $append) = myRegister("I:cust S:format S:append");
 
 if (!$_POST) {
    myError($w,$p, my_("You cannot reload or bookmark this page!"));
@@ -109,7 +109,7 @@ if ($format=="xml") {
             $data[4]="";
          }
          $data[5]="";
-         ProcessRow($ds, $cust, $w,$p, $data, FALSE);
+         ProcessRow($ds, $cust, $w,$p, $data, FALSE, $append);
       }
    }
 }
@@ -135,7 +135,7 @@ else {
         insert($w,textbr());
         insert($w,text(my_("Importing row:")." $rowcnt "));
 
-        ProcessRow($ds, $cust, $w, $p, $data, $template);
+        ProcessRow($ds, $cust, $w, $p, $data, $template, $append);
     }
     fclose ($fp);
 }
@@ -146,7 +146,7 @@ printhtml($p);
 
 // $data is number indexed array that has format of ip, user, location, 
 // description, telephone
-function ProcessRow($ds, $cust, &$w, &$p, $data, $template) {
+function ProcessRow($ds, $cust, &$w, &$p, $data, $template, $append) {
 
     global $format;
 
@@ -158,24 +158,24 @@ function ProcessRow($ds, $cust, &$w, &$p, $data, $template) {
         return;
     }
     // bogus row
-    if ($num<6) {
+    if ($num<7) {
         // ok to save what has been imported already
         $ds->DbfTransactionEnd();
         myError($w,$p, my_("Row not the correct format."));
     }
 
-    if (testIP($data[0])) {
+    if (testIP(trim($data[0]))) {
         insert($w,block("<b>".my_("Invalid IP address")."</b>"));
         return;
     }
 
-    $ip=inet_aton($data[0]);
+    $ip=inet_aton(trim($data[0]));
     $user=substr($data[1],0,80);
     $location=substr($data[2],0,80);
     $descrip=substr($data[3],0,80);
     $hname=substr($data[4],0,100);
     $telno=substr($data[5],0,15);
-    $macaddr="";
+    $macaddr=substr($data[6],0,12);
     if ($format=="xml") {
         $macaddr=$data[6];
     }
@@ -183,7 +183,7 @@ function ProcessRow($ds, $cust, &$w, &$p, $data, $template) {
     $info="";
     if (is_object($template)) {
         // all columns over 6 are considered for adding to template fields
-        $cnt=6;
+        $cnt=7;
         $userfld=array();
         foreach($template->userfld as $key=>$value) {
             // set fields in template only if field in import file exists, else make blank
@@ -215,13 +215,22 @@ function ProcessRow($ds, $cust, &$w, &$p, $data, $template) {
     $baseaddr=$row["baseaddr"];
     $subnetsize=$row["subnetsize"];
 
+    if ($append == "on") {
+        $ip=(array)$ip;
+        if ($user==="NULL") $user="";
+        if ($location==="NULL") $location="";
+        if ($telno==="NULL") $telno="";
+        if ($macaddr==="NULL") $macaddr="";
+        if ($descrip==="NULL") $descrip="";
+        if ($hname==="NULL") $hname="";
+    }
     if ($ds->ModifyIP($ip, $baseindex, $user, $location, 
                 $telno, $macaddr, $descrip, $hname, $info) == 0) {
         insert($w,text(my_("IP address details modified")));
     }
-    else
+    else {
         insert($w,text(my_("IP address details could not be modified")));
-
+    }
 }
 
 ?>
