@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 $auth = new BasicAuthenticator(ADMINREALM, REALMERROR);
 
@@ -173,22 +174,32 @@ if ($action=="custindex") {
     insert($t,$ck = cell());
     insert($ck,text(my_("Action")));
 
+    //capture data for the export view functionality
+    $export = new exportForm();
+    $export->addRow(array("customer_description", "group_name", "customer_ID"));
+    $export->saveRow();
+    
     $cnt=0;
     while($row = $result->FetchRow()) {
         if (strtolower($row["custdescrip"]) == "all") {
             continue;
         }
-
+        $export->addRow(NULL);
+        
         setdefault("cell",array("class"=>color_flip_flop()));
 
         insert($t,$c = cell());
         insert($c,text($row["custdescrip"]));
-
+        $export->addCell($row["custdescrip"]);
+        
         insert($t,$c = cell());
         insert($c,text($row["admingrp"]));
+        $export->addCell($row["admingrp"]);
 
         insert($t,$c = cell());
         insert($c,text($row["customer"]));
+        $export->addCell($row["customer"]);
+        $export->saveRow();
 
         insert($t,$c = cell());
         insert($c,block("<small>"));
@@ -216,6 +227,11 @@ if ($action=="custindex") {
             $printed=1;
         }
     }
+    
+   // create the export view form
+   $export->setInfo(array(array("maintenance_page"),
+                          array("customer index")));
+   $export->createExportForm($w, NULL);
 }
 
 if ($action=="reqindex") {
@@ -224,8 +240,7 @@ if ($action=="reqindex") {
             FROM requestip, customer
             WHERE customer.customer=requestip.customer
             ORDER BY customer.custdescrip");
-
-
+            
     $totcnt=0;
     $vars="";
     // fastforward till first record if not first block of data
@@ -255,24 +270,37 @@ if ($action=="reqindex") {
     insert($t,$ck = cell());
     insert($ck,text(my_("Action")));
 
+    //capture data for the export view functionality
+    $export = new exportForm();
+    $export->addRow(array("customer_description", "request_description", "user", "user_description", "request_date"));
+    $export->saveRow();
+    
     $cnt=0;
     while($row = $result->FetchRow()) {
+	    $export->addRow(NULL);
+	    
         setdefault("cell",array("class"=>color_flip_flop()));
 
         insert($t,$c = cell());
         insert($c,text($row["custdescrip"]));
-
+        $export->addCell($row["custdescrip"]);
+        
         insert($t,$c = cell());
         insert($c,text($row["requestdesc"]));
+        $export->addCell($row["requestdesc"]);
 
         insert($t,$c = cell());
         insert($c,text($row["userinf"]));
+        $export->addCell($row["userinf"]);
 
         insert($t,$c = cell());
         insert($c,text($row["descrip"]));
+        $export->addCell($row["descrip"]);
 
         insert($t,$c = cell());
         insert($c,block($result->UserTimeStamp($row["lastmod"], "M d Y H:i:s")));
+        $export->addCell($row["lastmod"]);
+        $export->saveRow();
 
         insert($t,$c = cell());
         insert($c,block("<small>"));
@@ -299,7 +327,11 @@ if ($action=="reqindex") {
             $printed=1;
         }
     }
-
+    
+   //create the export view form
+   $export->setInfo(array(array("maintenance_page"),
+                          array("request index")));
+   $export->createExportForm($w, NULL);
 }
 
 
