@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 //
 
 // when the database layout changes, bump up this value.
-define("SCHEMA", 21);
+define("SCHEMA", 22);
 
 require_once("../ipplanlib.php");
 //require_once('../adodb/adodb-errorhandler.inc.php');
@@ -29,7 +29,7 @@ require_once("../auth.php");
 
 // check for latest variable added to config.php file, if not there
 // user did not upgrade properly
-if (!defined("REQUESTREPLYBLIND")) die("Your config.php file is inconsistent - you cannot use your old config.php file during upgrade");
+if (!defined("FQDNREGEX")) die("Your config.php file is inconsistent - you cannot use your old config.php file during upgrade");
 
 $auth = new BasicAuthenticator(ADMINREALM, REALMERROR);
 
@@ -92,7 +92,7 @@ $indexes['base']=array(
 $tables['baseadd']=array(
    array('baseindex', 'I8', 'DEFAULT' => 0, 'NotNull', 'PRIMARY'),
    array('info', 'X', 'DEFAULT' => ''),
-   array('infobin', 'B', 'DEFAULT' => '', 'Null'),
+   array('infobin', (DBF_TYPE=='oci8po') ? 'XL':'B', 'DEFAULT' => '', 'Null'),
    array('infobinfn', 'C', '255', 'DEFAULT' => '', 'Null')
 );
 
@@ -171,7 +171,7 @@ $tables['ipaddradd']=array(
    array('ipaddr', (DBF_TYPE=='mysql' or DBF_TYPE=='maxsql') ? 'INT UNSIGNED':'I8', 'DEFAULT' => 0, 'NotNull', 'PRIMARY'),
    array('baseindex', 'I8', 'DEFAULT' => 0, 'NotNull', 'PRIMARY'),
    array('info', 'X', 'DEFAULT' => ''),
-   array('infobin', 'B', 'DEFAULT' => '', 'Null'),
+   array('infobin', (DBF_TYPE=='oci8po') ? 'XL':'B', 'DEFAULT' => '', 'Null'),
    array('infobinfn', 'C', '255', 'DEFAULT' => '', 'Null')
 );
 $indexes['ipaddradd']=array(
@@ -249,6 +249,7 @@ else {
 $tables['users']=array(
    array('userid', 'C', '40', 'DEFAULT' => '', 'NotNull', 'PRIMARY'),
    array('userdescrip', 'C', '80', 'DEFAULT' => '', 'NotNull'),
+   array('useremail', 'C', '64', 'DEFAULT' => '', 'Null'),
    array('password', 'C', '40', 'DEFAULT' => '', 'NotNull')
 );
 
@@ -275,7 +276,7 @@ $tables['fwdzone']=array(
    array('data_id', 'I8', 'AUTOINCREMENT', 'NotNull', 'PRIMARY'),
    array('domain', 'C', '254', 'DEFAULT' => '', 'NotNull'),
    array('createmod', 'D', 'DEFAULT' => '', 'Null'),
-   array('lastmod', 'D', 'DEFAULT' => '', 'Null'),
+   array('lastmod', 'T', 'DEFAULT' => '', 'Null'),
    array('regmod', 'D', 'DEFAULT' => '', 'Null'),
    array('expiremod', 'T', 'DEFAULT' => '', 'Null'),
    array('engineer', 'C', '254', 'DEFAULT' => '', 'Null'),
@@ -984,6 +985,24 @@ function UpdateSchema($display) {
           }
        }
 
+     case 21:
+       $sqlarray = $dict->AddColumnSQL("users",
+               array(array('useremail', 'C', '64', 'DEFAULT' => '', 'Null')));
+
+       foreach($sqlarray as $value) {
+           if (!$display) {
+               if (!$ds->Execute($value)) {
+                   PrintSQL($value);
+                   echo "Failed to execute above statement against database<p>";
+                   echo "<b>".$ds->ErrorMsg()."</b>";
+                   exit;
+               }
+           } else {
+               PrintSQL($value);
+           }
+       }
+
+
 
 
        // end switch
@@ -1116,6 +1135,13 @@ if (!is_writeable(UPLOADDIRECTORY) or !is_readable(UPLOADDIRECTORY)) {
 if (!is_writeable(DNSEXPORTPATH)) {
    echo "<p>\n\n#DNS zone file exports do not work - unable to create file in ".DNSEXPORTPATH." - check permissions<br>\n";
 }
+if (!is_writeable(DHCPEXPORTPATH)) {
+   echo "<p>\n\n#DHCP exports do not work - unable to create file in ".DHCPEXPORTPATH." - check permissions<br>\n";
+}
+// not currently used
+#if (!is_writeable(VIEWEXPORTPATH)) {
+#   echo "<p>\n\n#View exports do not work - unable to create file in ".VIEWEXPORTPATH." - check permissions<br>\n";
+#}
 // cannot use is_executable() function here - only for php > 5.x
 if (NMAP != "") {
     if (!@file_exists(NMAP)) {   // to stop fork errors on older php versions
@@ -1192,7 +1218,7 @@ else {
     }
    UpdateSchema($display);
    if ($display) {
-      echo "<b>#The above commands need to be executed by the administrator to update the database schema for IPplan to v4.86a. There may be no commands required.</b>\n";
+      echo "<b>#The above commands need to be executed by the administrator to update the database schema for IPplan to v4.91a. There may be no commands required.</b>\n";
    }
    else {
       echo "<b>The database schema was updated</b>";
