@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -302,7 +302,8 @@ function insertEditUserForm($w,$ds) {
     insert($w, $t=table(array("cols"=>"2","border"=>"0","cellspacing"=>"2","width"=>"100%")));
     insert($t, $c=cell());
     insert($c ,block("<b>".my_("Editing User: $userid")."</b><br>"));
-    insert($c, block("<i>".my_("Real Name: ").$row["userdescrip"]."</i>"));
+    insert($c, block("<i>".my_("Real Name: ").$row["userdescrip"]."</i><br>"));
+    insert($c, block(my_("e-mail: ").$row["useremail"]));
     insert($t, $c=cell(array("align"=>"right")));
     insert($c, $f = form(array("method"=>"post","action"=>$_SERVER["PHP_SELF"])));
     insert($f,hidden(array("name"=>"action","value"=>"deleteuser")));
@@ -618,7 +619,7 @@ function insertEditGroupForm($w,$ds) {
 
 function insertCreateUserForm($w,$ds) {
 
-    list($userid, $userdescrip, $grp)= myRegister("S:userid S:userdescrip S:grp");
+    list($userid, $userdescrip, $useremail, $grp)= myRegister("S:userid S:userdescrip S:useremail S:grp");
     insert($w, $f = form(array("method"=>"post",
                     "action"=>$_SERVER["PHP_SELF"])));
     insert($f,hidden(array("name"=>"action","value"=>"parsecreateuserform")));
@@ -635,6 +636,11 @@ function insertCreateUserForm($w,$ds) {
                     "value"=>"$userdescrip",
                     "size"=>"40",
                     "maxlength"=>"80")));
+    insert($con,textbrbr(my_("User's e-mail:")));
+    insert($con,input_text(array("name"=>"useremail",
+                    "value"=>"$useremail",
+                    "size"=>"40",
+                    "maxlength"=>"64")));
     if (AUTH_INTERNAL) {
         insert($con,textbrbr(my_("Password (case sensitive!):")));
         insert($con,password(array("name"=>"password1",
@@ -666,11 +672,12 @@ function insertCreateUserForm($w,$ds) {
 
 function parseCreateUserForm($w,$ds) {
 
-    list($userid, $userdescrip, $password1, $password2, $grp, $search)=myRegister("S:userid S:userdescrip S:password1 S:password2 S:grp S:search");
+    list($userid, $userdescrip, $useremail, $password1, $password2, $grp, $search)=myRegister("S:userid S:userdescrip S:useremail S:password1 S:password2 S:grp S:search");
 
     $formerror="";
     $userid=trim($userid);
     $userdescrip=trim($userdescrip);
+    $useremail=trim($useremail);
     $search=trim($search);
     if (AUTH_INTERNAL) {
         $password1=trim($password1);
@@ -701,10 +708,11 @@ function parseCreateUserForm($w,$ds) {
         $result=&$ds->ds->Execute("DELETE FROM users
                 WHERE userid=".$ds->ds->qstr($userid));
         $result=&$ds->ds->Execute("INSERT INTO users
-                (userid, userdescrip, password)
+                (userid, userdescrip, useremail, password)
                 VALUES
                 (".$ds->ds->qstr($userid).",
                  ".$ds->ds->qstr($userdescrip).",
+                 ".$ds->ds->qstr($useremail).",
                  ".$ds->ds->qstr($password).")");
 
         // add group if user selected a group other than "No group"
