@@ -1,5 +1,5 @@
 <?php
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -139,8 +139,8 @@ exit;
                     $this->minimum=$rr->minimum;
                     $this->responsiblemail=$rr->rname;
                 }
-                if ($rr->type == "NS") {
-                    $this->hname[$i++]=$rr->nsdname;
+                if ($rr->type == "NS" and $rr->name == $this->domain) {
+                    $this->hname[$i++]=$this->strip_domain($rr->nsdname, $this->domain);
                 }
             }
 
@@ -227,6 +227,11 @@ class DNSfwdZone extends DNSZone {
                 $host=$this->strip_domain($rr->name, $this->domain);
                 $iphostname=$this->strip_domain($rr->cname, $this->domain);
             }
+            else if ($rr->type == "NS" and $rr->name != $this->domain) {
+                $recordtype=$rr->type;
+                $host=$this->strip_domain($rr->name, $this->domain);
+                $iphostname=$this->strip_domain($rr->nsdname, $this->domain);
+            }
             else if ($rr->type == "MX") {
                 $recordtype=$rr->type;
                 $host=$this->strip_domain($rr->name, $this->domain);
