@@ -1,5 +1,5 @@
 <?php
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -421,6 +421,10 @@ class IPplanIPTemplate {
         //echo "<pre>";var_dump($tmpl_def);echo "</pre>";
         return $tmpl_def;
     }
+    
+    function return_userfld(){
+	    return $this->userfld;
+    }
 }
 
 // NB - no space after last line here!
