@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -60,17 +60,17 @@ define("ADMINUSER", 'admin');
 define("ADMINPASSWD", 'admin');
 define("ADMINREALM", 'IPplan admin authentication');
 
-// allow anonymous read access to information? If TRUE, anybody
-// can view information, but authentication is required for all
-// changes. Depending on your security policy, setting this to
-// TRUE can be dangerous
-define("ANONYMOUS", FALSE);
-
 // setting to true logs all changes to the AuditLog
 define("AUDIT", TRUE);
 
 //---------------------START OF MISC SECTION-----------------
 
+// variable for enabling the view export functionality
+define("EXPORTENABLED", FALSE);
+
+// export path for portable export class functionality
+define("VIEWEXPORTPATH", "/tmp/export/");
+
 // field separator for import functions
 define("FIELDS_TERMINATED_BY", "\t");
 //define("FIELDS_TERMINATED_BY", ";");
@@ -118,6 +118,10 @@ define("HELPDESKEMAIL", 'helpdesk@mydomain.com');
 // email SMTP server/relay - either an ip address or domain name
 define("EMAILSERVER", 'localhost');
 
+// threshold in percents to warn subnet's admin by e-mail if subnet gets low
+// if 0, no warning
+define("SUBNETTHRESHOLD", 80);
+
 // enable or disable the request system
 define("REQUESTENABLED", TRUE);
 
@@ -141,6 +145,14 @@ define("REQUESTCUST", '');
 // DROP INDEX rangeaddr ON netrange;
 // ALTER TABLE netrange ADD  INDEX range_rangeaddr  (rangeaddr, customer);
 define("RANGETEST", 0);
+
+// the HNAMEREGEX constant is used to define a regular expression that host names adhere to.
+// it is used during record create/edit in various files
+define("HNAMEREGEX", '/^(([a-zA-Z0-9]+\.){0,})\.?([a-zA-Z0-9]+)$/');
+
+// the FQDNREGEX constant is used to match fully qualified domain names only
+define("FQDNREGEX", '/^(([a-zA-Z0-9]+\.[a-zA-Z0-9]+){1,})\.([a-zA-Z0-9]+)$/');
+
 //-------------------------START OF REGISTRAR---------------------------
 
 // enable and disable SWIP/resgistrar functionality (only useful if 
@@ -240,6 +252,7 @@ define("LANGCHOICE", TRUE);
 // Each line defines an available theme and gives it a name.
 
 $config_themes = array (
+    "Red Grey" => "red_grey.css",
     "Classic" => "default.css",
     "Pastel"  => "pastel.css",
     "Penguin" => "penguin.css");
