@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@ require_once("layout/class.layout");
 
 // check for latest variable added to config.php file, if not there
 // user did not upgrade properly
-if (!defined("REQUESTREPLYBLIND")) die("Your config.php file is inconsistent - you cannot use your old config.php file during upgrade");
+if (!defined("FQDNREGEX")) die("Your config.php file is inconsistent - you cannot use your old config.php file during upgrade");
 
 // set language
 isset($_COOKIE["ipplanLanguage"]) && myLanguage($_COOKIE['ipplanLanguage']);
