@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -503,6 +503,13 @@ function location_uri($relative_url) {
     }
 }
 
+// finds URL's in a string and converts them to links
+function linkURL($txt) {
+    return preg_replace( 
+    '/(http|ftp|telnet)+(s)?:(\/\/)((\w|\.)+)(\/)?(\S+)?/i', 
+                  '<a href="\0">\4</a>', $txt);
+}
+
 // This function returns the username of the current user
 // as reported by PHP, with special handling for IIS.
  
@@ -616,7 +623,7 @@ function myheading($q, $title, $displaymenu=true) {
 
     insert($w,$con=container("div",array("class"=>"normalbox")));
     insert($w,$con1=container("div",array("class"=>"footerbox")));
-    insert($con1,block("IPPlan v4.86a"));
+    insert($con1,block("IPPlan v4.91a"));
     return $con;
 
 }
