@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,13 +23,12 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
-if (!ANONYMOUS) {
-   $auth = new SQLAuthenticator(REALM, REALMERROR);
+$auth = new SQLAuthenticator(REALM, REALMERROR);
 
-   // And now perform the authentication
-   $grps=$auth->authenticate();
-}
+// And now perform the authentication
+$grps=$auth->authenticate();
 
 // save the last customer used
 // must set path else Netscape gets confused!
@@ -159,10 +158,16 @@ if (REGENABLED) {
 }
 
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("subnet_addr", "subnet_size", "subnet_mask", "description", "last_modified", "changed_by", "update_sent"));
+$export->saveRow();
+
 $cnt=0;
 $prevrow="";
 while($row = $result->FetchRow()) {
 setdefault("cell",array("class"=>color_flip_flop()));
+    $export->addRow(NULL);
 
     // customer is 0, display all customers with customer description
     // on customer change
@@ -183,35 +188,44 @@ setdefault("cell",array("class"=>color_flip_flop()));
     insert($t,$c = cell());
     insert($c,anchor("displaysubnet.php?baseindex=".$row["baseindex"], 
                      inet_ntoa($row["baseaddr"])));
-
+    $export->addCell(inet_ntoa($row["baseaddr"]));
+                     
     if ($row["subnetsize"] == 1) {
         insert($t,$c = cell());
         insert($c,text(my_("Host")));
+        $export->addCell(my_("Host"));
     }
     else {
         insert($t,$c = cell());
         insert($c,text($row["subnetsize"]));
+        $export->addCell($row["subnetsize"]);
     }
 
     insert($t,$c = cell());
     insert($c,text(inet_ntoa(inet_aton(ALLNETS)+1 -
                     $row["subnetsize"])."/".inet_bits($row["subnetsize"])));
-
+    $export->addCell(inet_ntoa(inet_aton(ALLNETS)+1 - $row["subnetsize"])."/".inet_bits($row["subnetsize"]));
+                    
     insert($t,$c = cell());
     insert($c,text($row["descrip"]));
+    $export->addCell($row["descrip"]);
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,block($result->UserTimeStamp($row["lastmod"], "M d Y H:i:s")));
     insert($c,block("</small>"));
+    $export->addCell($row["lastmod"]);
     insert($t,$c = cell());
     insert($c,text($row["userid"]));
+    $export->addCell($row["userid"]);
     if (REGENABLED) {
        insert($t,$c = cell());
        insert($c,block("<small>"));
        insert($c,block($result->UserTimeStamp($row["swipmod"], "M d Y H:i:s")));
        insert($c,block("</small>"));
     }
-
+    $export->addCell($row["swipmod"]);
+    $export->saveRow();
+    
     if ($totcnt % MAXTABLESIZE == MAXTABLESIZE-1)
        break;
     $cnt++;
@@ -238,6 +252,13 @@ while ($row = $result->FetchRow()) {
 }
 
 $result->Close();
+
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("customer_ID", "customer_description", "area_ID", "range_ID", "search_criterion", "search_expression"),
+                       array($cust, $ds->getCustomerDescrip($cust), $areaindex, $rangeindex, $expression, $descrip)));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
