@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,13 +23,12 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
-if (!ANONYMOUS) {
-   $auth = new SQLAuthenticator(REALM, REALMERROR);
+$auth = new SQLAuthenticator(REALM, REALMERROR);
 
-   // And now perform the authentication
-   $grps=$auth->authenticate();
-}
+// And now perform the authentication
+$grps=$auth->authenticate();
 
 // set language
 isset($_COOKIE["ipplanLanguage"]) && myLanguage($_COOKIE['ipplanLanguage']);
@@ -93,10 +92,16 @@ insert($ck,text(my_("Action")));
 // do this here else will do extra queries for every customer
 $adminuser=$ds->TestGrpsAdmin($grps);
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("customer_description", "CRM", "group_name"));
+$export->saveRow();
+
 $cnt=0;
 while($row = $result->FetchRow()) {
 setdefault("cell",array("class"=>color_flip_flop()));
-
+   $export->addRow(NULL);
+   
    // strip out customers user may not see due to not being member
    // of customers admin group. $grps array could be empty if anonymous
    // access is allowed!
@@ -109,12 +114,17 @@ setdefault("cell",array("class"=>color_flip_flop()));
 
    insert($t,$c = cell());
    insert($c,text($row["custdescrip"]));
-
+   $export->addCell($row["custdescrip"]);
+   
    insert($t,$c = cell());
    insert($c,text($row["crm"]));
+   $export->addCell($row["crm"]);
 
    insert($t,$c = cell());
    insert($c,text($row["admingrp"]));
+   $export->addCell($row["admingrp"]);
+   
+   $export->saveRow();
 
    insert($t,$c = cell());
    insert($c,block("<small>"));
@@ -158,6 +168,13 @@ while ($row = $result->FetchRow()) {
 }
 
 $result->Close();
+
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("search_criterion", "search_expression"),
+                 array($expression, $search)));
+$export->createExportForm($w, $template);
+
 printhtml($p);
 
 ?>
