@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
-
+require_once("../class.xptlib.php");
 require_once("../class.templib.php");
 
 // display the telephone number (TRUE) or mac address (FALSE) in the output table
@@ -86,6 +86,7 @@ if (!$row = $result->FetchRow()) {
 }
 $maxcnt=$row["subnetsize"];
 $baseaddr=$row["baseaddr"];
+$netdescrip=$row["descrip"];
 $cust=$row["customer"];
 
 // script gets called back from modifyipform script so that user does
@@ -211,7 +212,7 @@ if ($_POST) {
                 // check if mac address is valid - all or nothing!
                 if (!empty($macaddr)) {
                     $oldmacaddr=$macaddr;
-                    $macaddr=str_replace(array(":", "-", " "), "", $macaddr);
+                    $macaddr=str_replace(array(":", "-", ".", " "), "", $macaddr);
                     if (strlen($macaddr)==12 and
                             preg_match("/^[a-f0-9A-F]*$/", $macaddr)) {
                         // check for duplicate mac address - only when subnet is marked as DHCP
@@ -235,6 +236,61 @@ if ($_POST) {
                 if ($err==FALSE and $ds->ModifyIP($ip, $baseindex, $user, $location, 
                             $telno, $macaddr, $descrip, $hname, $info) == 0) {
 
+                    // ----- handle alerts if subnet gets low  ----------
+
+                    // count recs without network and broadcast addr
+                    $recs=$ds->ds->GetOne("SELECT count(*) FROM ipaddr
+                            WHERE baseindex=$baseindex AND
+                            ipaddr!=$baseaddr AND
+                            ipaddr!=$baseaddr+$maxcnt-1");
+                    $utilization=($recs+2)/$maxcnt*100;
+
+                    // send en e-mail if threshold is exceeded
+                    if (SUBNETTHRESHOLD != 0 and $utilization>SUBNETTHRESHOLD) {
+                        // Get e-mail of all admins of the subnet
+                        $adminemails=$ds->ds->GetCol("SELECT DISTINCT(useremail) FROM base,usergrp,users
+                            WHERE baseindex=$baseindex AND
+                            usergrp.grp=base.admingrp AND
+                            users.userid=usergrp.userid");
+
+                        // Test if there is really someone to send a mail
+                        foreach($adminemails as $emailtmp) {
+                            if (!empty($emailtmp)) {
+                                $sendwarningmail=TRUE;
+                            }
+                        }
+
+                        if ($sendwarningmail) {
+                            require_once("../class.phpmailer.php");
+                            $mail = new PHPMailer();
+                            $mail->IsSMTP(); // telling the class to use SMTP
+                            $mail->SetLanguage("en", "../");
+                            $mail->Host = EMAILSERVER; // SMTP server
+                            $mail->From = HELPDESKEMAIL;
+                            $mail->IsHTML(false);
+                            $mail->FromName = "IP Plan";
+                            foreach($adminemails as $emailtmp) {
+                                if (!empty($emailtmp)) {
+                                    $mail->AddAddress($emailtmp);
+                                }
+                            }
+                            $mail->Subject = "[IPplan] Subnet ".inet_ntoa($baseaddr)."/".inet_bits($maxcnt)." gets low";
+                            $mail->Body="Subnet ".inet_ntoa($baseaddr)."/".inet_bits($maxcnt)." exdeeded ".SUBNETTHRESHOLD."% of utilization.\n";
+                            $mail->Body.="Total addresses: $maxcnt\n";
+                            $mail->Body.="Used addresses: ".($recs+2)." (including network and broadcast)\n";
+                            $mail->Body.="Free addresses: ".($maxcnt-$recs-2)."\n";
+                            $mail->Body.="Utilization: $utilization%\n";
+                            if(!@$mail->Send()) {
+                                $formerror .= my_("E-mail message was not sent")."\n";
+                                $formerror .= my_("Mailer Error: ") . $mail->ErrorInfo;
+                            }
+                            else {
+                                insert($w,textbr(my_("Warning E-mail message sent (utilization threshold exceeded)")));
+                            }
+
+                        }
+                    }
+
                     // ----- handle email requests back to user ----------
 
                     // ok, we actioned an ip address request - delete the request record
@@ -291,7 +347,7 @@ if ($_POST) {
                             else {
 
                                 //Send email notification that IP Request was entered 
-                                require("../class.phpmailer.php");
+                                require_once("../class.phpmailer.php");
                                 $mail = new PHPMailer();
                                 $mail->IsSMTP(); // telling the class to use SMTP
                                 $mail->SetLanguage("en", "../");
@@ -359,11 +415,14 @@ $result=$ds->GetSubnetDetails($baseindex, $sql);
 // emulate for databases that do not have RecordCount
 if (empty($search)) {
     // no search, count recs without network and broadcast addr
-    $recs=$ds->ds->GetOne("SELECT count(*) AS cnt
-                           FROM ipaddr
-                           WHERE baseindex=$baseindex AND 
-                           ipaddr!=$baseaddr AND 
-                           ipaddr!=$baseaddr+$maxcnt-1");
+    // $recs may have already been computed
+    if (!isset($recs)) {
+        $recs=$ds->ds->GetOne("SELECT count(*) AS cnt
+                               FROM ipaddr
+                               WHERE baseindex=$baseindex AND 
+                               ipaddr!=$baseaddr AND 
+                               ipaddr!=$baseaddr+$maxcnt-1");
+    }
 }
 else {
     $recs=$result->PO_RecordCount("ipaddr", "baseindex=$baseindex $sql");
@@ -381,12 +440,16 @@ if ($baseaddr+$block*MAXTABLESIZE >= $baseaddr+$maxcnt) {
 }
 
 insert($w,block("<h3>"));
+insert($w,textbr(my_("Customer/autonomous system description:")." ".$ds->GetCustomerDescrip($cust)));
 insert($w,text(my_("Subnet:")." ".
                   inet_ntoa($baseaddr)." ".my_("Mask:")." ".
                   inet_ntoa(inet_aton(ALLNETS)+1 -
                     $maxcnt)."/".inet_bits($maxcnt)));
 insert($w,textbr());
-insert($w,text(my_("Description:")." ".$row["descrip"]));
+insert($w,text(my_("Description:")." ".$netdescrip));
+insert($w,block("<small>"));
+insert($w,anchor("modifybase.php?cust=$cust&descrip=".urlencode($netdescrip),my_("Delete/Edit/Modify/Split/Join Subnet")));
+insert($w,block("</small>"));
 /* not all vars available for link
     insert($w,anchor("modifysubnet.php?baseindex=".$row["baseindex"].
                      "&areaindex=".$areaindex."&rangeindex=".$rangeindex.
@@ -542,10 +605,17 @@ if ($showactive and NMAP != "") {
     }
 }
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("ip_addr", "user", "location", "description", "hostname", (TELNO? "telephone":"mac_address"), "last_polled", "last_modified", "changed_by"));
+$export->saveRow();
+
 $pollcnt=array("d"=>0, "w"=>0, "m"=>0, "y"=>0);
 $cnt=0;
 $lst=array();
 while($row = $rr->FetchRow()) {
+	$export->addRow(NULL);
+	
     setdefault("cell",array("class"=>color_flip_flop()));
 
     // work out inet_ntoa once as it is slow!
@@ -587,20 +657,22 @@ while($row = $rr->FetchRow()) {
     insert($c,anchor($lnk, $ip));
 //    insert($c,block(sprintf(' <A HREF="." ONCLICK="window.open(\'%s&close=1\', \'Name\', \'width=1000,height=600,toolbar=yes,scrollbars=yes\'); return false;">&rArr;</A>', $lnk)));
     insert($c,block(sprintf(' <A HREF="." ONCLICK="window.open(\'%s&close=1\', \'Name\', \'width=1000,height=600,toolbar=yes,scrollbars=yes\'); return false;">&#8634;</A>', $lnk)));
+    $export->addCell($ip);
     
-
     insert($t,$c = cell());
     // network address
     if (SHOWRESERVED and $maxcnt > 2 and $row["ipaddr"] == $baseaddr) {
         insert($c,text(my_("Reserved - network address"), 
                     array("color"=>"#FF0000")));
         insert($c,textbr());
+        $export->addCell(my_("Reserved - network address"));
     }
     // broadcast address
     else if (SHOWRESERVED and $maxcnt > 2 and $row["ipaddr"] == $baseaddr+$maxcnt-1) {
         insert($c,text(my_("Reserved - broadcast address"), 
                     array("color"=>"#FF0000")));
         insert($c,textbr());
+        $export->addCell(my_("Reserved - broadcast address"));
     }
     else {
         // add to select drop down list
@@ -617,6 +689,9 @@ while($row = $rr->FetchRow()) {
         $lnk=substr($lnk, 3);
     }
     insert($c,textbr($userinf));
+    
+    $export->addCell($userinf);
+    
     if (!empty($lnk)) {
         insert($c,block("<small><i>"));
         insert($c,anchor("displaybase.php?ipaddr=$lnk&cust=$cust&searchin=1&jump=1",
@@ -626,8 +701,10 @@ while($row = $rr->FetchRow()) {
 
     insert($t,$c = cell());
     insert($c,text($row["location"]));
+    $export->addCell($row["location"]);
     insert($t,$c = cell());
-    insert($c,text($row["descrip"]));
+    insert($c,block(linkURL(htmlspecialchars($row["descrip"]))));
+    $export->addCell($row["descrip"]);
     if ($showdns) {
         // gethostbyaddr returns ip address back if no DNS entry
         // this will probably fail on windows!
@@ -659,13 +736,17 @@ while($row = $rr->FetchRow()) {
         insert($c,text($row["hname"]));
         insert($c,block("</i></small>"));
     }
+    $export->addCell($row["hname"]);
+    
     if (TELNO) {
         insert($t,$c = cell());
         insert($c,text($row["telno"]));
+        $export->addCell($row["telno"]);
     }
     else {
         insert($t,$c = cell());
         insert($c,text(substr(chunk_split($row["macaddr"], 2, ':'), 0, -1)));
+        $export->addCell(substr(chunk_split($row["macaddr"], 2, ':'), 0, -1));
     }
 
     // display info about when last device was polled
@@ -686,13 +767,17 @@ while($row = $rr->FetchRow()) {
         insert($c,text("Y"));
         $pollcnt["y"]++;
     }
-
+    $export->addCell($row["lastpol"]);
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,block($result->UserTimeStamp($row["lastmod"], "M d Y H:i:s")));
     insert($c,block("</small>"));
+    $export->addCell($row["lastmod"]);
     insert($t,$c = cell());
     insert($c,text($row["userid"]));
+    $export->addCell($row["userid"]);
+    $export->saveRow();
 
     if ($totcnt % MAXTABLESIZE == MAXTABLESIZE-1)
         break;
@@ -755,6 +840,13 @@ if ($block > 0) {
 insert($ck1,textb(my_("IP address")));
 
 $result->Close();
+
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("customer_ID", "customer_description", "subnet_ID", "search_criterion", "search_expression", "total_addresses", "used_addresses", "free_addresses", "active_polled(D_W_M_Y)", "utilization", "efficiency"),
+                       array($cust, $ds->getCustomerDescrip($cust), $baseindex, $expression, $descrip, $maxcnt, ($recs+2)."(including network and broadcast)", ($maxcnt-$recs-2), ($pollcnt["d"]."_".$pollcnt["w"]."_".$pollcnt["m"]."_".$pollcnt["y"]), round(($recs+2)/$maxcnt*100,2), round(($recs)/$maxcnt*100,2))));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 
@@ -826,7 +918,7 @@ function DeleteDNS($ds, $w, $cust, $ip) {
 
     $formerror = "";
 
-    if (DNSAUTOCREATE) {
+    if (DNSAUTOCREATE === TRUE) {
         // check if there are A records for this customers domains?
         $result = &$ds->ds->Execute("SELECT fwdzone.domain, fwdzone.data_id, fwdzonerec.host, 
                 fwdzonerec.ip_hostname, fwdzonerec.recidx
@@ -880,7 +972,7 @@ function UpdateDNS($ds, $w, $cust, $hname, $ip) {
         $formerror .= sprintf(my_("Invalid hostname: %s %s"), inet_ntoa($ip), 
                 $hname)."\n";
     }
-    else {
+    else if (DNSAUTOCREATE === TRUE) {
         // check if there are A records for this customers domains?
         $result = &$ds->ds->Execute("SELECT fwdzone.data_id, fwdzone.domain, fwdzonerec.host, 
                 fwdzonerec.ip_hostname 
@@ -939,8 +1031,7 @@ function UpdateDNS($ds, $w, $cust, $hname, $ip) {
         // no matching A records to update, now look for a zone to create a 
         // new A record in - only supported on MySQL and Postgres (databases that support
         // regex searches
-        else if (DNSAUTOCREATE and 
-            (DBF_TYPE=="mysql" or DBF_TYPE=="maxsql" or DBF_TYPE=="postgres7") and 
+        else if ((DBF_TYPE=="mysql" or DBF_TYPE=="maxsql" or DBF_TYPE=="postgres7") and 
             $recs==0) {
             
             $regex = "RLIKE";
