@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -122,17 +122,18 @@ insert($w, $f = form(array("name"=>"swiptosend",
 
 $cnt=0;
 while($row = $result->FetchRow()) {
-
+    $temparray2 = array();
+    
     $swip=genSWIP($ds, $row["baseindex"], inet_ntoa($row["baseaddr"]), 
             inet_ntoa($row["baseaddr"]+$row["subnetsize"]-1), 
-            $cust, $row["descrip"], $filename);
+            $cust, $row["descrip"], $row["swipmod"], $filename);
     if ($swip == FALSE)
         myError($w,$p, my_("Error reading template!"));
 
     insert($f,block("<pre>"));
     insert($f,text($swip));
     insert($f,block("</pre>"));
-
+    
     $ind=$row["baseindex"];
     insert($f,checkbox(array("name"=>"baseindex[]",
                     "value"=>"$ind"),
