@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -80,9 +80,10 @@ foreach($baseindex as $key => $value) {
 
    $baseip=inet_ntoa($row["baseaddr"]);
    $size=$row["subnetsize"];
+   $swipmod=$row["swipmod"];
    $swip=genSWIP($ds, $value, $baseip, 
                       inet_ntoa($row["baseaddr"]+$size-1), 
-                      $cust, $row["descrip"], $filename);
+                      $cust, $row["descrip"], $swipmod, $filename);
 
    insert($w,block("<pre>"));
    insert($w,text($swip));
