@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -137,6 +137,7 @@ while($row = $result->FetchRow()) {
                 htmlspecialchars($size), htmlspecialchars($broadcast)));
 
     //$template->Merge($template->decode($rowadd["info"]));
+    fputs($fp, sprintf("\t<description>%s</description>\n", $descrip));
     foreach($template->userfld as  $field=>$val) {
         fputs($fp, sprintf("\t<%s>%s</%s>\n", 
                     htmlspecialchars($field),
@@ -152,6 +153,8 @@ while($row = $result->FetchRow()) {
             userinf LIKE ".$ds->ds->qstr("%".DHCPRESERVED."%")."
             ORDER BY ipaddr");
 
+    $iprange_dynamicIPs=array();
+    $iprange_fixedIPs=array();
     while ($rowip = $result_ip->FetchRow()) {
         $ipaddr=inet_ntoa($rowip["ipaddr"]);
         $macaddr=$rowip["macaddr"];
@@ -178,16 +181,39 @@ while($row = $result->FetchRow()) {
 
                 fputs($fp, sprintf("\t\t<macaddr>%s</macaddr>\n", 
                             htmlspecialchars(substr(chunk_split($macaddr, 2, ':'), 0, -1))));
+                $iprange_fixedIPs[]=$rowip["ipaddr"];
             }
             else {
                 insert($w,textbr(sprintf(my_("Found IP with invalid MAC - ignoring: %s, %s"), $ipaddr, $macaddr)));
             }
-
+        } else {
+            $iprange_dynamicIPs[]=$rowip["ipaddr"];
         }
         fputs($fp, "\t</host>\n");
 
     } // end while: loop through ips of subnet. 
 
+    // Loop through the dynamic IPs above, and print the ranges.
+    $iprange_start=$iprange_dynamicIPs[0];
+    for ($i=0; $i<count($iprange_dynamicIPs); $i++) {
+        if ($iprange_dynamicIPs[$i]+1 != $iprange_dynamicIPs[$i+1]) {
+	    fputs($fp, sprintf("\t<iprange type=\"dynamic\" firstip=\"%s\" lastip=\"%s\" />\n",
+			htmlspecialchars(inet_ntoa($iprange_start)),
+			htmlspecialchars(inet_ntoa($iprange_dynamicIPs[$i]))));
+	    $iprange_start=$iprange_dynamicIPs[$i+1];
+	}
+    }
+
+    $iprange_start=$iprange_fixedIPs[0];
+    for ($i=0; $i<count($iprange_fixedIPs); $i++) {
+        if ($iprange_fixedIPs[$i]+1 != $iprange_fixedIPs[$i+1]) {
+            fputs($fp, sprintf("\t<iprange type=\"static\" firstip=\"%s\" lastip=\"%s\" />\n",
+                        htmlspecialchars(inet_ntoa($iprange_start)),
+                        htmlspecialchars(inet_ntoa($iprange_fixedIPs[$i]))));
+            $iprange_start=$iprange_fixedIPs[$i+1];
+        }
+    }
+
     fputs($fp, sprintf("</network>\n"));
 
 } // end while
