@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,17 +23,16 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 define("DUPWARN", "~D~");
 define("DUPWARNFREE", "~F~");
 define("MAXSIZE", 99999999);
 
-if (!ANONYMOUS) {
-   $auth = new SQLAuthenticator(REALM, REALMERROR);
+$auth = new SQLAuthenticator(REALM, REALMERROR);
 
-   // And now perform the authentication
-   $auth->authenticate();
-}
+// And now perform the authentication
+$auth->authenticate();
 
 // save the last customer used
 // must set path else Netscape gets confused!
@@ -187,6 +186,11 @@ insert($c,text(my_("Utilization")));
 insert($t,$c = cell());
 insert($c,text(my_("Barchart")));
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("subnet_addr", "subnet_size", "subnet_mask", "description", "utilization"));
+$export->saveRow();
+
 for ($i=0; $i < $maxcnt; $i++) {
     setdefault("cell",array("class"=>color_flip_flop()));
 
@@ -215,11 +219,18 @@ for ($i=0; $i < $maxcnt; $i++) {
                 insert($t,$c = cell(array("class"=>"greencell")));
                 insert($c,anchor("createsubnetform.php?ipaddr=".$start."&cust=".$cust, 
                             $start));
+                $export->addRow(NULL);
+                $export->addCell($start);
                 insert($t,$c = cell());
                 insert($c,text($newsize));
+                $export->addCell($newsize);
+                $export->addCell("");
                 insert($t,$c = cell());
                 insert($t,$c = cell());
                 insert($c,text(my_("Free space")));
+                $export->addCell(my_("free space"));
+                $export->addCell("");
+                $export->saveRow();
                 insert($t,$c = cell());
                 insert($t,$c = cell());
                 $width=100;
@@ -255,7 +266,7 @@ for ($i=0; $i < $maxcnt; $i++) {
                             inet_ntoa($arr[$i]["baseaddr"])));
             }
         }
-
+        
         if ($arr[$i]["subnetsize"] == 1) {
             insert($t,$c = cell());
             insert($c,text(my_("Host")));
@@ -270,6 +281,13 @@ for ($i=0; $i < $maxcnt; $i++) {
                         $arr[$i]["subnetsize"])."/".inet_bits($arr[$i]["subnetsize"])));
 
         insert($t,$c = cell());
+        
+        $export->addRow(NULL);
+	
+        $export->addCell(inet_ntoa($arr[$i]['baseaddr']));
+        $export->addCell($arr[$i]['subnetsize']);        
+        $export->addCell(inet_ntoa(inet_aton(ALLNETS)+1 - $arr[$i]['subnetsize'])."/".inet_bits($arr[$i]['subnetsize']));
+       
         // hack to make it more intuitive for ISP's
         if ($free) {
             insert($c,text(my_("Free/Unassigned space")));
@@ -278,13 +296,16 @@ for ($i=0; $i < $maxcnt; $i++) {
             if ($arr[$i]["descrip"]==DUPWARN) {
                 insert($c,span(my_("SPACE IS ASSIGNED OVER MULTIPLE CUSTOMERS/AS's"), 
                             array("class"=>"textError")));
+                $export->addCell(my_("SPACE IS ASSIGNED OVER MULTIPLE CUSTOMERS/AS's"));   
             }
             else if ($arr[$i]["descrip"]==DUPWARNFREE) {
                 insert($c,span(my_("SPACE IS ASSIGNED OVER MULTIPLE CUSTOMERS/AS's AND CONTAINS SPACE MARKED FREE"), 
                             array("class"=>"textError")));
+                $export->addCell(my_("SPACE IS ASSIGNED OVER MULTIPLE CUSTOMERS/AS's AND CONTAINS SPACE MARKED FREE"));
             }
             else {
                 insert($c,text($arr[$i]["descrip"]));
+                $export->addCell($arr[$i]["descrip"]);
             }
         }
         // display utilization
@@ -292,14 +313,18 @@ for ($i=0; $i < $maxcnt; $i++) {
         if ($arr[$i]["subnetsize"] == 1) {
             insert($c,text("1/100%"));
             $used++;
+            $export->addCell("1/100%");            
         }
         else {
             insert($c,text(($arr[$i]["cnt"]+2)."/".
                         round(($arr[$i]["cnt"]+2)/$arr[$i]["subnetsize"]*100,2)."%"));
             // add reserved addresses
             $used+=$arr[$i]["cnt"]+2;
+            $export->addCell(($arr[$i]['cnt']+2)."/".round(($arr[$i]['cnt']+2)/$arr[$i]['subnetsize']*100,2)."%");
         }
-
+        
+        $export->saveRow();
+        
         // display barchart
         insert($t,$c = cell());
         if ($arr[$i]["subnetsize"] == 1) {
@@ -327,11 +352,18 @@ for ($i=0; $i < $maxcnt; $i++) {
             insert($c,anchor("createsubnetform.php?ipaddr=".$newbase.
                         "&cust=".$cust."&size=".$newsize, 
                         $newbase));
+            $export->addRow(NULL);
+            $export->addCell($newbase);
             insert($t,$c = cell());
             insert($c,text($newsize));
+            $export->addCell($newsize);
+            $export->addCell("");
             insert($t,$c = cell());
             insert($t,$c = cell());
             insert($c,text(my_("Free space")));
+            $export->addCell(my_("Free space"));
+            $export->addCell("");
+            $export->saveRow();
             insert($t,$c = cell());
             insert($t,$c = cell());
             $width=100;
@@ -339,7 +371,7 @@ for ($i=0; $i < $maxcnt; $i++) {
         }
 
     }
-
+    
     $cnt++;
     if ($arr[$i]["subnetsize"] > 2) {
         $cntsubnets+=2;
@@ -359,11 +391,18 @@ if ($cnt and $showused != 2) {
                         inet_ntoa($arr[$i-1]["baseaddr"]+$arr[$i-1]["subnetsize"]).
                         "&cust=".$cust, 
                         inet_ntoa($arr[$i-1]["baseaddr"]+$arr[$i-1]["subnetsize"])));
+            $export->addRow(NULL);          
+            $export->addCell(inet_ntoa($arr[$i-1]["baseaddr"]+$arr[$i-1]["subnetsize"]));
             insert($t,$c = cell());
             insert($c,text($newsize));
+            $export->addCell($newsize);
+            $export->addCell("");
             insert($t,$c = cell());
             insert($t,$c = cell());
             insert($c,text(my_("Free space")));
+            $export->addCell(my_("Free space"));
+            $export->addCell("");
+            $export->saveRow();
             insert($t,$c = cell());
             insert($t,$c = cell());
             $width=100;
@@ -376,13 +415,21 @@ if ($cnt and $showused != 2) {
 if ($showused == 1 and $size_from == 0 and $size_to == MAXSIZE) {
     insert($t,$c = cell());
     insert($c,textb(my_("Total:")));
+    $export->addRow(NULL);
+    $export->addCell(my_("Total:"));
     insert($t,$c = cell());
     insert($c,textb($endnum-$startnum+1));
+    $export->addCell($endnum-$startnum+1);
+    $export->addCell("");
+    $export->addCell("");
     insert($t,$c = cell());
     insert($t,$c = cell());
     insert($t,$c = cell());
     insert($c,textb($used));
+    $export->addCell($used);
 
+    $export->saveRow();
+        
     insert($w,block("<p>"));
     insert($w,textb(my_("NOTE: Host and two host subnets are always 100% allocated")));
     insert($w,block("<p>"));
@@ -427,6 +474,11 @@ echo memory_get_usage(); // php >=4.3 only
 }
 */
 
+// create the export view form
+$export->setInfo(array(array("customer_ID", "customer_description", "addr_start", "addr_end", "total_allocated_networks_subnets", "percent_network_subnets_allocated", "total_unassigned_subnets", "percent_unassigned_subnets", "percent_ip_allocated_include_reserved", "percent_ip_allocated_exclude_reserved"),
+                       array($cust, $ds->getCustomerDescrip($cust), $start, $end, $cnt, round($cntsubsize/($endnum-$startnum+1)*100, 2), $cntfree, round($cntfreesubsize/($endnum-$startnum+1)*100, 2), round($used/($endnum-$startnum+1)*100, 2), round(($used-($cntsubnets*2))/($endnum-$startnum+1)*100, 2))));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
