@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -24,12 +24,10 @@ require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
 
-if (!ANONYMOUS) {
-   $auth = new SQLAuthenticator(REALM, REALMERROR);
+$auth = new SQLAuthenticator(REALM, REALMERROR);
 
-   // And now perform the authentication
-   $grps=$auth->authenticate();
-}
+// And now perform the authentication
+$grps=$auth->authenticate();
 
 // set language
 isset($_COOKIE["ipplanLanguage"]) && myLanguage($_COOKIE['ipplanLanguage']);
