@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -91,10 +92,14 @@ insert($c,text(my_("Description")));
 insert($t,$c = cell());
 insert($c,text(my_("Action")));
 
- 
+$export = new exportForm();
+$export->addRow(array("area_addr", "area_description", "range_addr", "range_size", "range_mask", "range_description"));
+$export->saveRow();
+
 $cnt=0;
 $savearea=0;
 while($row=$result->FetchRow()) {
+	$export->addRow(Null);
     setdefault("cell",array("class"=>color_flip_flop()));
 
     // first record could be NULL due to left join
@@ -102,6 +107,8 @@ while($row=$result->FetchRow()) {
         insert($t,$c = cell());
         insert($t,$c = cell());
         insert($t,$c = cell());
+        $export->addCell(inet_ntoa($row["areaaddr"]));
+        $export->addCell($row["adescrip"]);
     }
     else {
         if (is_numeric($row["areaaddr"])) {
@@ -109,9 +116,11 @@ while($row=$result->FetchRow()) {
             insert($c,anchor("displaybase.php?&cust=".$cust."&rangeindex=0".
                      "&areaindex=".$row["areaindex"]."&ipaddr=&descrip=&size=0",
                      inet_ntoa($row["areaaddr"])));
-
+            $export->addCell(inet_ntoa($row["areaaddr"]));
+                     
             insert($t,$c = cell());
             insert($c,text($row["adescrip"]));
+            $export->addCell($row["adescrip"]);
 
             insert($t,$c = cell());
             insert($c,block("<small>"));
@@ -130,9 +139,11 @@ while($row=$result->FetchRow()) {
         else {
             insert($t,$c = cell());
             insert($c,text(my_("No area")));
+            $export->addCell(my_("No area"));
 
             insert($t,$c = cell());
             insert($c,text(my_("Range not part of area")));
+            $export->addCell(my_("Range not part of area"));
             insert($t,$c = cell());
         }
     }
@@ -141,16 +152,22 @@ while($row=$result->FetchRow()) {
     insert($c,anchor("displaybase.php?&cust=".$cust."&areaindex=0".
                      "&rangeindex=".$row["rangeindex"]."&ipaddr=&descrip=&size=0",
                      inet_ntoa($row["rangeaddr"])));
+    $export->addCell(inet_ntoa($row["rangeaddr"]));
 
     insert($t,$c = cell());
     insert($c,text($row["rangesize"]));
+    $export->addCell($row["rangesize"]);
 
     insert($t,$c = cell());
     insert($c,text(inet_ntoa(inet_aton(ALLNETS)+1 -
                     $row["rangesize"])."/".inet_bits($row["rangesize"])));
+    $export->addCell(inet_ntoa(inet_aton(ALLNETS)+1 - $row["rangesize"])."/".inet_bits($row["rangesize"]));
 
     insert($t,$c = cell());
     insert($c,text($row["rdescrip"]));
+    $export->addCell($row["rdescrip"]);
+    
+    $export->saveRow();
 
     insert($t,$c = cell());
     insert($c,block("<small>"));
@@ -173,6 +190,7 @@ while($row=$result->FetchRow()) {
 }
 insert($w,block("<p>"));
 insert($w,textb(sprintf(my_("Total records: %u"), $cnt)));
+$temp1 = $cnt;
 
 $result=&$ds->ds->Execute("SELECT area.areaaddr,
                              area.descrip AS adescrip, area.areaindex
@@ -200,16 +218,25 @@ insert($c,text(my_("Action")));
 
 $cnt=0;
 while($row=$result->FetchRow()) {
+	$export->addRow(NULL);
+	
     setdefault("cell",array("class"=>color_flip_flop()));
 
     insert($t,$c = cell());
     // no point in making this a hyperlink - there are no ranges so search will
     // always return nothing!
     insert($c,text(inet_ntoa($row["areaaddr"])));
-
+    $export->addCell(inet_ntoa($row["areaaddr"]));
+    
     insert($t,$c = cell());
     insert($c,text($row["adescrip"]));
-
+    $export->addCell($row["adescrip"]);
+    $export->addCell(my_("No range"));
+    $export->addCell("");
+    $export->addCell("");
+    $export->addCell(my_("No range in this area"));
+    $export->saveRow();
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,anchor("deletearea.php?areaindex=".$row["areaindex"]."&cust=".$cust,
@@ -228,8 +255,15 @@ while($row=$result->FetchRow()) {
 }
 insert($w,block("<p>"));
 insert($w,textb(sprintf(my_("Total records: %u"), $cnt)));
+$temp2 = $cnt;
 
 $result->Close();
+
+// create the export view form
+$export->setInfo(array(array("customer_ID", "customer_description", "total_ranges_and_areas_with_ranges", "total_areas_without_ranges"),
+                       array($cust, $ds->getCustomerDescrip($cust), $temp1, $temp2)));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
