@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -243,8 +243,10 @@ else if ($action=="split" or $action=="join") {
                 userid=".$ds->ds->qstr(getAuthUsername())."
                 WHERE baseindex=$baseindex");
         // ... and create new subnet
+        $timetmp=time();
+        // check that new decsription fits into 80 column field
         $basetmp=$ds->CreateSubnet(($base+($size/2)), $size/2, 
-                ($descriptmp." - ".time()), 
+                (substr($descriptmp, 0, 80-(strlen($timetmp)+3))." - ".$timetmp), 
                 $cust, 0, $admingrp);
         // ... and then link half of ip records to new subnet
         if ($basetmp) {
