@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@ require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
 require_once("../class.templib.php");
+require_once("../class.xptlib.php");
 
 //define("CRM_REGEX", '^[1234567890]*$');
 define("CRM_REGEX", '');
@@ -707,6 +708,12 @@ if (!$_POST || $formerror) {
     insert($legend,text(my_("Reverse DNS information (optional)")));
 
 
+    //capture data for the export view functionality
+    $export = new exportForm();
+    $export->addRow(array("hostname_1", "ip_addr_1","hostname_2", "ip_addr_2","hostname_3", "ip_addr_3","hostname_4", "ip_addr_4","hostname_5", "ip_addr_5","hostname_6", "ip_addr_6","hostname_7", "ip_addr_7","hostname_8", "ip_addr_8","hostname_9", "ip_addr_9","hostname_10", "ip_addr_10",));
+    $export->saveRow();
+    $export->addRow(NULL);
+    
     // space for 10 reverse entries
     for ($i=1; $i < 11; $i++) {
         insert($con,textbrbr(sprintf(my_("Hostname %u:"), $i)));
@@ -714,12 +721,14 @@ if (!$_POST || $formerror) {
                         "value"=>isset($hname[$i]) ? $hname[$i] : "",
                         "size"=>"80",
                         "maxlength"=>"80")));
+        $export->addCell(isset($hname[$i]) ? $hname[$i] : " ");
 
         insert($con,textbrbr(sprintf(my_("IP address %u:"), $i)));
         insert($con,input_text(array("name"=>"ipaddr[".$i."]",
                         "value"=>isset($ipaddr[$i]) ? $ipaddr[$i] : "",
                         "size"=>"15",
                         "maxlength"=>"15")));
+        $export->addCell(isset($ipaddr[$i]) ? $ipaddr[$i] : " ");
     }
 
     insert($f, $con=container("fieldset",array("class"=>"fieldset")));
@@ -819,6 +828,11 @@ if (!$_POST || $formerror) {
     insert($f,freset(array("value"=>my_("Clear"))));
     myCopyPaste($f, "ipplanCPcustomer", "ENTRY");
 
+    // create the export view form
+    $export->setInfo(array(array("customer_ID", "customer_description", "CRM", "group_name", "organization", "street", "city", "state", "zipcode", "country", "tech_contact_nickname", "tech_contact_last_name", "tech_contact_first_name", "tech_contact_middle_name", "tech_contact_org", "tech_contact_street", "tech_contact_city", "tech_contact_state", "tech_contact_zipcode", "tech_contact_country", "tech_contact_telephone", "tech_contact_email"),
+                       array($cust, $custdescrip, $crm, $grp, $org, $street, $city, $state, $zipcode, $cntry, $nichandl, $lname, $fname, $mname, $torg, $tstreet, $tcity, $tstate, $tzipcode, $tcntry, $phne, $mbox)));
+$export->createExportForm($w, $template);
+
 }
 
 printhtml($p);
