@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn February 2003
@@ -27,6 +27,7 @@ require_once("../class.dnslib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
 require_once("../class.templib.php");
+require_once("../class.xptlib.php");
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -185,8 +186,8 @@ if ($action=="add" or $action=="edit") {
     if (!checkdate($expiremonth, $expireday, $expireyear)) {
       myError($w,$p, my_("Invalid expire date"));
     }
-    if ("$expireyear$expiremonth$expireday" >= "$regyear$regmonth$regday" AND 
-        "$regyear$regmonth$regday" >= "$createyear$createmonth$createday") {
+    if ((sprintf("%04u%02u%02u",$expireyear,$expiremonth,$expireday) >= sprintf("%04u%02u%02u",$regyear,$regmonth,$regday)) AND 
+        (sprintf("%04u%02u%02u",$regyear,$regmonth,$regday) >= sprintf("%04u%02u%02u",$createyear,$createmonth,$createday))) {
 
     }
     else {
@@ -333,6 +334,13 @@ if ($action=="export") {
             myError($w,$p, my_("Could not find the zone - possibly deleted by another user"));
         }
 
+        $serialnum = $ds->ds->GetOne("SELECT serialnum
+                FROM fwdzone
+                WHERE customer=$cust AND data_id=$value");
+        $serialdate = $ds->ds->GetOne("SELECT serialdate
+                FROM fwdzone
+                WHERE customer=$cust AND data_id=$value");
+
         $ds->SetSerial($serialdate, $serialnum);
         // dont really need customer, but required for now
         $ds->cust=$cust;
@@ -449,10 +457,15 @@ insert($c,text(my_("Changed by")));
 insert($t,$ck = cell());
 insert($ck,text(my_("Action")));
 
+// capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("domain", "primary_DNS", "secondary_DNS", "serial_date", "ttl", "refresh", "retry", "expire", "minimum_ttl", "last_modified", "last_exported", "changed_by"));
+$export->saveRow();
 
 $cnt=0;
 while($row = $result->FetchRow()) {
 setdefault("cell",array("class"=>color_flip_flop()));
+    $export->addRow(NULL);
 
     insert($t,$c = cell());
     // have zone records been modified
@@ -463,8 +476,14 @@ setdefault("cell",array("class"=>color_flip_flop()));
     else {
         insert($c,text($row["domain"]));
     }
+    
     if ($row["slaveonly"] == "Y") {
         insert($c,span(my_("Slave zone"), array("class"=>"textSmall")));
+        
+        $export->addCell($row["domain"].my_(" (Slave zone)"));
+    }
+    else {
+    $export->addCell($row["domain"]);
     }
 
     $result1 = &$ds->ds->Execute("SELECT hname FROM fwddns
@@ -474,39 +493,52 @@ setdefault("cell",array("class"=>color_flip_flop()));
     insert($t,$c = cell());
     $row1 = $result1->FetchRow();
     insert($c,text($row1["hname"]));
-
+    $export->addCell($row1["hname"]);
+    
     insert($t,$c = cell());
     $row1 = $result1->FetchRow();
     insert($c,text($row1["hname"]));
-
+    $export->addCell($row1["hname"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["serialdate"].str_pad($row["serialnum"], 2, '0', STR_PAD_LEFT)));
-
+    $export->addCell($row["serialdate"].str_pad($row["serialnum"], 2, '0', STR_PAD_LEFT));
+    
     insert($t,$c = cell());
     insert($c,text($row["ttl"]));
-
+    $export->addCell($row["ttl"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["refresh"]));
-
+    $export->addCell($row["refresh"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["retry"]));
-
+    $export->addCell($row["retry"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["expire"]));
-
+    $export->addCell($row["expire"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["minimum"]));
-
+    $export->addCell($row["minimum"]);
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,block($result->UserTimeStamp($row["lastmod"], "M d Y H:i:s")));
+    $export->addCell($row["lastmod"]);
     insert($c,block("<br>"));
     insert($c,block($result->UserTimeStamp($row["lastexp"], "M d Y H:i:s")));
     insert($c,block("</small>"));
+    $export->addCell($row["lastexp"]);
 
     insert($t,$c = cell());
     insert($c,text($row["userid"]));
-
+    $export->addCell($row["userid"]);
+    
+    $export->saveRow();
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,anchor($_SERVER["PHP_SELF"]."?cust=$cust&dataid=".$row["data_id"]."&action=delete&domain=".urlencode($row["domain"]), my_("Delete DNS Zone"),
@@ -552,7 +584,7 @@ setdefault("cell",array("class"=>color_flip_flop()));
                 my_("Whois")));
 
     insert($c,block("</small>"));
-
+    
     if ($totcnt % MAXTABLESIZE == MAXTABLESIZE-1)
         break;
     $cnt++;
@@ -589,6 +621,13 @@ insert($f,submit(array("value"=>my_("Add a DNS Zone"))));
 
 
 $result->Close();
+
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("customer_ID", "customer_description", "search_criterion", "search_expression"),
+                       array($cust, $ds->getCustomerDescrip($cust), $expression, $descrip)));
+$export->createExportForm($w, $template);
+
 printhtml($p);
 
 ?>
