@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn Feburary 2003
@@ -26,6 +26,7 @@ require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
 require_once("../class.templib.php");
+require_once("../class.xptlib.php");
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -69,21 +70,16 @@ if (!$_GET) {
 // result, close connection
 $ds=new IPplanDbf() or myError($w,$p, my_("Could not connect to database"));
 
-$now = getdate();
-$newserialdate = $now["year"] . str_pad($now["mon"], 2, '0', STR_PAD_LEFT) . str_pad( $now["mday"], 2, '0', STR_PAD_LEFT);
-if ($serialdate=$newserialdate) {
-   $serialnum++;
-}else{
-   $serialdate=$newserialdate;
-   $serialnum=0;
-}
-
 insert($w, $f = form(array("name"=>"ENTRY",
                            "method"=>"post",
                            "action"=>"modifydns.php")));
 
 // Use the same form for adding or editing.  Setup page & variables based on action.
 if ($action=='add') {
+    $now = getdate();
+    $serialdate = $now["year"] . str_pad($now["mon"], 2, '0', STR_PAD_LEFT) . str_pad( $now["mday"], 2, '0', STR_PAD_LEFT);
+    $serialnum=0;
+
     $zone="";
 
     $ttl=DNSTTL;
@@ -140,7 +136,7 @@ if ($action=="add") {
                     "size"=>"30",
                     "maxlength"=>"30")));
 
-    $result2=&$ds->ds->Execute("SELECT hname 
+    $result2=&$ds->ds->Execute("SELECT hname,horder
             FROM revdns
             WHERE customer=$cust");
 
@@ -202,7 +198,7 @@ else {
         $regyear = $regmonth = $regday = "";
     }
 
-    $result2=&$ds->ds->Execute("SELECT hname 
+    $result2=&$ds->ds->Execute("SELECT hname,horder 
             FROM fwddns
             WHERE id=$dataid");
 }
@@ -250,22 +246,10 @@ $months=array("1"=>my_("January"),
               "10"=>my_("October"),
               "11"=>my_("November"),
               "12"=>my_("December"));
-$years=array("1995"=>"1995",
-             "1996"=>"1996",
-             "1997"=>"1997",
-             "1998"=>"1998",
-             "1999"=>"1999",
-             "2000"=>"2000",
-             "2001"=>"2001",
-             "2002"=>"2002",
-             "2003"=>"2003",
-             "2004"=>"2004",
-             "2005"=>"2005",
-             "2006"=>"2006",
-             "2007"=>"2007",
-             "2008"=>"2008",
-             "2009"=>"2009",
-             "2010"=>"2010");
+
+$years=array();
+$i = 1994;
+while ($i < date('Y')+15) $years[$i++] = $i;
 
 // create a table
 insert($f, $con=container("fieldset",array("class"=>"fieldset")));
@@ -323,10 +307,16 @@ else {
  
 $i=1;
 while($row2 = $result2->FetchRow()) {
-   $hname[$i]=$row2["hname"];
+   $hname[$row2["horder"]]=$row2["hname"];
    $i++;
 }
 
+// capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("name_server_1", "name_server_2", "name_server_3", "name_server_4", "name_server_5", "name_server_6", "name_server_7", "name_server_8", "name_server_9", "name_server_10"));
+$export->saveRow();
+$export->addRow(NULL);
+
 // space for 10 reverse entries
 for ($i=1; $i < 11; $i++) {
     insert($con,textbr(sprintf(my_("Name server %u:"), $i)));
@@ -335,7 +325,10 @@ for ($i=1; $i < 11; $i++) {
                                "size"=>"80",
                                "maxlength"=>"100")));
     insert($con,textbr());
+ 
+    $export->addCell(isset($hname[$i]) ? $hname[$i] : "");
 }
+$export->saveRow();
 
 insert($f, $con=container("fieldset",array("class"=>"fieldset")));
 insert($con, $legend=container("legend",array("class"=>"legend")));
@@ -415,6 +408,10 @@ insert($f,submit(array("value"=>my_("Save"))));
 insert($f,freset(array("value"=>my_("Clear"))));
 myCopyPaste($f, "ipplanCPdnsrecord", "ENTRY");
 
-printhtml($p);
+// create the export view form
+$export->setInfo(array(array("customer_ID", "customer_description", "data_ID", "domain", "email", "serialdate", "serialnum", "ttl", "retry", "refresh", "expire", "minimum_ttl", "slave_zone", "zone_path", "second_zone_path"),
+                       array($cust, $ds->getCustomerDescrip($cust), $dataid, $domain, $responsiblemail, $serialdate, $serialnum, $ttl, $retry, $refresh, $expire, $minimum, $slaveonly, $zonepath, $seczonepath)));                      
+$export->createExportForm($w, $template);
 
+printhtml($p);
 ?>
