@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn February 2003
@@ -25,6 +25,9 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
+
+define("FQDNHNAMEREGEX", '/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/');
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -202,16 +205,25 @@ if ($action=="add" or $action=="edit") {
         $formerror .= my_("Bind @ shortcut converted to Fully Qualified Domain Name (FQDN)")."\n";
         $host=$domain.".";
     }
+    /*
+    if ($host === "*") {
+        $formerror .= my_("Bind * shortcut converted to Fully Qualified Domain
+                Name (FQDN)")."\n";
+        $host="*.".$domain.".";
+    } */
 
     // Error Checks
+    if (strpos($host, "_") or strpos($iphostname, "_")) {
+        myError($w,$p, my_("Invalid IP/ Hostname"));
+    }
     if ($recordtype=="MX") {   // MX could have no hostname
-        if ($host and !preg_match('/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/', $host)) {
+        if ($host and !preg_match(FQDNHNAMEREGEX, $host)) {
             myError($w,$p, my_("Invalid hostname"));
         }
     } else {
         if (!$host)
             myError($w,$p, my_("Host may not be blank"));
-        if (!preg_match('/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/', $host))
+        if (!preg_match(FQDNHNAMEREGEX, $host))
             myError($w,$p, my_("Invalid hostname"));
     }
     if (!$recordtype)
@@ -225,13 +237,13 @@ if ($action=="add" or $action=="edit") {
         list($preference, $iphost) = explode(" ", $iphostname, 2);
         // is it correct format?
         if (is_numeric($preference) and $preference >= 0) {
-            if (!preg_match('/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/', $iphost)) {
+            if (!preg_match(FQDNHNAMEREGEX, $iphost)) {
                 myError($w,$p, my_("Invalid IP/ Hostname"));
             }
         }
         // no just a hostname? then add a default preference of 10.
         else {
-            if (!preg_match('/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/', $iphostname)) {
+            if (!preg_match(FQDNHNAMEREGEX, $iphostname)) {
                 myError($w,$p, my_("Invalid IP/ Hostname"));
             }
             $iphostname="10 ".$iphostname;
@@ -246,7 +258,7 @@ if ($action=="add" or $action=="edit") {
         // is it correct format?
         if (is_numeric($priority) and is_numeric($weight) and is_numeric($port)
                    and $priority >= 0        and $weight >= 0        and $port >= 0 ) {
-            if (!preg_match('/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/', $iphost)) {
+            if (!preg_match(FQDNHNAMEREGEX, $iphost)) {
                 myError($w,$p, my_("Invalid IP/ Hostname"));
             }
         }
@@ -271,8 +283,8 @@ if ($action=="add" or $action=="edit") {
     if ($recordtype=="A" and testIP($iphostname))
         myError($w,$p, my_("For A type, IP / Hostname must be an IP address"));
     // need to check for valid host
-    if ($recordtype=="CNAME") {
-        if (!preg_match('/^(([\w][\w\-\.]*)\.)?([\w][\w\-]+)(\.([\w][\w\.]*))?\.?$/', $iphostname))
+    if ($recordtype=="CNAME" or $recordtype=="NS") {
+        if (!preg_match(FQDNHNAMEREGEX, $iphostname))
             myError($w,$p, my_("Invalid IP/ Hostname"));
     }
 
@@ -501,6 +513,7 @@ if ($domain) {
 
     $arr=$_GET;
     $arr["domain"]=$domain;
+    $arr["cust"]=$cust;
     $arr["action"]="";
     $srch = new mySearch($w, $arr, $descrip, "descrip");
     $srch->legend=my_("Refine Search on Host");
@@ -548,10 +561,15 @@ insert($c,text(my_("Changed by")));
 insert($t,$ck = cell());
 insert($ck,text(my_("Action")));
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("sort_order", "host", "record_type", "ip_hostname", "last_modified", "changed_by"));
+$export->saveRow();
 
 $cnt=0;
 while($row = $result->FetchRow()) {
 setdefault("cell",array("class"=>color_flip_flop()));
+    $export->addRow(NULL);
 
     $temphost=$row["host"];
     $tempiphostname=$row["ip_hostname"];
@@ -567,12 +585,16 @@ setdefault("cell",array("class"=>color_flip_flop()));
     */
     insert($t,$c = cell());
     insert($c,text($row["sortorder"]));
-
+    $export->addCell($row["sortorder"]);
+    
     insert($t,$c = cell());
     insert($c,text($temphost));
-
+    $export->addCell($temphost);
+    
     insert($t,$c = cell());
     insert($c,text($row["recordtype"]));
+    $export->addCell($row["recordtype"]);
+    
     // auto created record?
     if ($row["error_message"]=="A") {
         insert($c,block(" <small><i>"));
@@ -582,15 +604,20 @@ setdefault("cell",array("class"=>color_flip_flop()));
 
     insert($t,$c = cell());
     insert($c,text($tempiphostname));
-
+    $export->addCell($tempiphostname);
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,block($result->UserTimeStamp($row["lastmod"], "M d Y H:i:s")));
     insert($c,block("</small>"));
-
+    $export->addCell($row["lastmod"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["userid"]));
-
+    $export->addCell($row["userid"]);
+    
+    $export->saveRow();
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,checkbox(array("name"=>"dataid[]",
@@ -679,6 +706,13 @@ else {
 }
    
 $result->Close();
+
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("customer_ID", "customer_description", "search_criterion", "search_expression"),
+                       array($cust, $ds->getCustomerDescrip($cust), $expression, $descrip)));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
