@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn Feburary 2003
@@ -25,6 +25,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -120,6 +121,7 @@ insert($con,selectbox(array("A"=>"A",
                           "TXT"=>"TXT",
                           "KEY"=>"KEY",
                           "SRV"=>"SRV",
+                          "NS"=>"NS",
                           "AFSDB"=>"AFSDB"),
                           array("name"=>"recordtype"), $recordtype));
 
@@ -142,6 +144,12 @@ insert($f,submit(array("value"=>my_("Save"))));
 insert($f,freset(array("value"=>my_("Clear"))));
 myCopyPaste($f, "ipplanCPdnsrecord", "ENTRY");
 
+// create the export view form
+$export = new exportForm();
+$export->setInfo(array(array("customer_ID", "customer_description", "data_ID", "domain", "sort_order", "host", "record_type", "ip_hostname"),
+                       array($cust, $ds->getCustomerDescrip($cust), $dataid, $domain, $sortorder, $host, $recordtype, $iphostname)));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
