@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
-
+require_once("../class.xptlib.php");
 require_once("../class.templib.php");
 
 // first element of "Additional data" section of modifyipform page
@@ -64,12 +64,10 @@ function FindNextFree($ds, $baseindex, $baseaddr, $subnetsize) {
 }
 
 
-if (!ANONYMOUS) {
-   $auth = new SQLAuthenticator(REALM, REALMERROR);
+$auth = new SQLAuthenticator(REALM, REALMERROR);
 
-   // And now perform the authentication
-   $auth->authenticate();
-}
+// And now perform the authentication
+$auth->authenticate();
 
 // set language
 isset($_COOKIE["ipplanLanguage"]) && myLanguage($_COOKIE['ipplanLanguage']);
@@ -285,6 +283,7 @@ $md5str=$ds->GetMD5($ip, $baseindex);
 myError($w,$p, $formerror, FALSE);
 
 insert($w,block("<h3>"));
+insert($w,textbr(my_("Customer/autonomous system description:")." ".$ds->GetCustomerDescrip($cust)));
 insert($w,text(my_("Subnet:")." ".
                   inet_ntoa($baseaddr)." ".my_("Mask:")." ".
                   inet_ntoa(inet_aton(ALLNETS)+1 -
@@ -296,6 +295,9 @@ if (isset($_SERVER['HTTP_REFERER']) and stristr($_SERVER['HTTP_REFERER'], "displ
 insert($w,block("</small>"));
 insert($w,textbr());
 insert($w,text(my_("Description:")." ".$netdescrip));
+insert($w,block("<small>"));
+insert($w,anchor("modifybase.php?cust=$cust&descrip=".urlencode($netdescrip),my_("Delete/Edit/Modify/Split/Join Subnet")));
+insert($w,block("</small>"));
 insert($w,block("</h3>"));
 
 // ------------------- request ip address section starts here ------------------------
@@ -767,6 +769,17 @@ insert($f,hidden(array("name"=>"searchin",
 insert($f,hidden(array("name"=>"jump",
                       "value"=>"1")));
 
+// create the export view form
+$export = new exportForm();
+$export->addRow(array("user", "location", "description", "hostname", "telephone", "mac_addr", "linked_addr"));
+$export->saveRow();
+$export->addRow(array($userinf, $location, $descrip, $hname, $telno, $macaddr, $lnk));
+$export->saveRow();
+
+$export->setInfo(array(array("subnet_ID", "subnet_addr", "subnet_mask", "subnet_description", "ip_address"),
+                       array($baseindex, inet_ntoa($baseaddr), (inet_ntoa(inet_aton(ALLNETS)+1 - $subnetsize)."/".inet_bits($subnetsize)), $netdescrip, $ip)));                      
+$export->createExportForm($w, $template);
+                      
 printhtml($p);
 
 ?>
