@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn February 2003
@@ -26,6 +26,7 @@ require_once("../class.dbflib.php");
 require_once("../class.dnslib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -286,6 +287,13 @@ if ($action=="export") {
 	        myError($w,$p, my_("Could not find the zone - possibly deleted by another user"));
 	    }
 
+        $serialnum = $ds->ds->GetOne("SELECT serialnum
+                FROM zones
+                WHERE customer=$cust AND id=$value");
+        $serialdate = $ds->ds->GetOne("SELECT serialdate
+                FROM zones
+                WHERE customer=$cust AND id=$value");
+
 	    $ds->SetSerial($serialdate, $serialnum);
 	    // dont really need customer, but required for now
 	    $ds->cust=$cust;
@@ -403,9 +411,16 @@ insert($c,text(my_("Changed by")));
 insert($t,$ck = cell());
 insert($ck,text(my_("Action")));
 
+//capture data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("zone", "primary_DNS", "secondary_DNS", "serial_date", "ttl", "refresh", "retry", "expire", "minimum_ttl", "last_modified", "last_exported", "changed_by"));
+$export->saveRow();
+
 $cnt=0;
 while($row = $result->FetchRow()) {
-    setdefault("cell",array("class"=>color_flip_flop()));
+    $export->addRow(NULL);
+	
+	setdefault("cell",array("class"=>color_flip_flop()));
 
     insert($t,$c = cell());
     if ($row["error_message"] == "E" or $ds->RevZoneChanged($cust, $row["id"])) {
@@ -415,13 +430,17 @@ while($row = $result->FetchRow()) {
     else {
         insert($c,text($row["zone"]));
     }
-
+    
 //    insert($c,text($row["zone"]));
     insert($c,textbr());
     insert($c,block("<small><i>"));
     if ($row["slaveonly"] == "Y") {
         insert($c,text(my_("Slave zone")));
-        insert($c,textbr());
+        insert($c,textbr());    
+        $export->addCell($row["zone"].my_(" (Slave zone)")." ".inet_ntoa($row['zoneip'])."/".inet_bits($row['zonesize']));
+    }
+    else {
+	    $export->addCell($row["zone"]." ".inet_ntoa($row['zoneip'])."/".inet_bits($row['zonesize']));
     }
     insert($c,anchor("findfree.php?cust=$cust&showused=1".
                 "&start=".inet_ntoa($row["zoneip"]).
@@ -429,7 +448,6 @@ while($row = $result->FetchRow()) {
                 inet_ntoa($row["zoneip"])."/".inet_bits($row["zonesize"])));
     insert($c,block("</i></small>"));
 
-
     $result1 = &$ds->ds->Execute("SELECT hname FROM zonedns
             WHERE id=".$row["id"]."
             ORDER BY horder");
@@ -437,39 +455,52 @@ while($row = $result->FetchRow()) {
     insert($t,$c = cell());
     $row1 = $result1->FetchRow();
     insert($c,text($row1["hname"]));
-
+    $export->addCell($row1["hname"]);
+    
     insert($t,$c = cell());
     $row1 = $result1->FetchRow();
     insert($c,text($row1["hname"]));
-
+    $export->addCell($row1["hname"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["serialdate"].str_pad($row["serialnum"], 2, '0', STR_PAD_LEFT)));
-
+    $export->addCell($row["serialdate"].str_pad($row["serialnum"], 2, '0', STR_PAD_LEFT));
+    
     insert($t,$c = cell());
     insert($c,text($row["ttl"]));
-
+    $export->addCell($row["ttl"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["refresh"]));
-
+    $export->addCell($row["refresh"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["retry"]));
-
+    $export->addCell($row["retry"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["expire"]));
-
+    $export->addCell($row["expire"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["minimum"]));
-
+    $export->addCell($row["minimum"]);
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,block($result->UserTimeStamp($row["lastmod"], "M d Y H:i:s")));
+    $export->addCell($row["lastmod"]);
     insert($c,block("<br>"));
     insert($c,block($result->UserTimeStamp($row["lastexp"], "M d Y H:i:s")));
     insert($c,block("</small>"));
-
+    $export->addCell($row["lastexp"]);
+    
     insert($t,$c = cell());
     insert($c,text($row["userid"]));
-
+    $export->addCell($row["userid"]);
+    
+    $export->saveRow();
+    
     insert($t,$c = cell());
     insert($c,block("<small>"));
     insert($c,anchor($_SERVER["PHP_SELF"]."?cust=$cust&zoneid=".$row["id"].
@@ -538,6 +569,13 @@ insert($w, $f = form(array("method"=>"post",
 insert($f,submit(array("value"=>my_("Add a Zone"))));
 
 $result->Close();
+
+// create the export view form
+$expression = $export->translateExpr($expr);
+$export->setInfo(array(array("customer_ID", "customer_description", "search_criterion", "search_expression"),
+                       array($cust, $ds->getCustomerDescrip($cust), $expression, $descrip)));
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
