@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn Feburary 2003
@@ -25,6 +25,7 @@ require_once("../adodb/adodb.inc.php");
 require_once("../class.dbflib.php");
 require_once("../layout/class.layout");
 require_once("../auth.php");
+require_once("../class.xptlib.php");
 
 $auth = new SQLAuthenticator(REALM, REALMERROR);
 
@@ -63,21 +64,16 @@ if (!$_GET) {
 // result, close connection
 $ds=new IPplanDbf() or myError($w,$p, my_("Could not connect to database"));
 
-$now = getdate();
-$newserialdate = $now["year"] . str_pad($now["mon"], 2, '0', STR_PAD_LEFT) . str_pad( $now["mday"], 2, '0', STR_PAD_LEFT);
-if ($serialdate=$newserialdate) {
-   $serialnum++;
-}else{
-   $serialdate=$newserialdate;
-   $serialnum=0;
-}
-
 insert($w, $f = form(array("name"=>"ENTRY",
                            "method"=>"post",
                            "action"=>"modifyzone.php")));
 
 // Use the same form for adding or editing.  Setup page & variables based on action.
 if ($action=='add') {
+    $now = getdate();
+    $serialdate = $now["year"] . str_pad($now["mon"], 2, '0', STR_PAD_LEFT) . str_pad( $now["mday"], 2, '0', STR_PAD_LEFT);
+    $serialnum=0;
+
     $zone="";
     $size=256;
 
@@ -190,6 +186,12 @@ while($row2 = $result2->FetchRow()) {
    $i++;
 }
 
+// arrays for capturing data for the export view functionality
+$export = new exportForm();
+$export->addRow(array("name_server_1", "name_server_2", "name_server_3", "name_server_4", "name_server_5", "name_server_6", "name_server_7", "name_server_8", "name_server_9", "name_server_10"));
+$export->saveRow();
+$export->addRow(NULL);
+
 // space for 10 reverse entries
 for ($i=1; $i < 11; $i++) {
     insert($con,textbrbr(sprintf(my_("Name server %u:"), $i)));
@@ -197,7 +199,10 @@ for ($i=1; $i < 11; $i++) {
                                "value"=>isset($hname[$i]) ? $hname[$i] : "",
                                "size"=>"80",
                                "maxlength"=>"100")));
+                               
+    $export->addCell(isset($hname[$i]) ? $hname[$i] : "");
 }
+$export->saveRow();
 
 insert($f, $con=container("fieldset",array("class"=>"fieldset")));
 insert($con, $legend=container("legend",array("class"=>"legend")));
@@ -262,6 +267,11 @@ insert($f,submit(array("value"=>my_("Save"))));
 insert($f,freset(array("value"=>my_("Clear"))));
 myCopyPaste($f, "ipplanCPzone", "ENTRY");
 
+// create the export view form
+$export->setInfo(array(array("customer_ID", "customer_description", "zoneid", "zone", "zone_ip", "email", "size", "serial_date", "serial_number", "ttl", "retry", "refresh", "expire", "minimum ttl", "slave_zone", "zone_path", "second_zone_path"),
+                       array($cust, $ds->getCustomerDescrip($cust), $zoneid, $zone, $zoneip, $responsiblemail, $size, $serialdate, $serialnum, $ttl, $retry, $refresh, $expire, $minimum, $slaveonly, $zonepath, $seczonepath)));            
+$export->createExportForm($w, NULL);
+
 printhtml($p);
 
 ?>
