@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -78,7 +78,7 @@ if ($_POST) {
     // check if mac address is valid - all or nothing!
     $newmacaddr="";
     if (!empty($macaddr)) {
-        $newmacaddr=str_replace(array(":", "-", " "), "", $macaddr);
+        $newmacaddr=str_replace(array(":", "-", ".", " "), "", $macaddr);
         if (strlen($newmacaddr)==12 and
                 preg_match("/[a-f0-9A-F]/", $newmacaddr)) {
         }
@@ -157,6 +157,7 @@ if ($_POST) {
             $mail->Body.="User information: $user\n";
             $mail->Body.="Location: $location\n";
             $mail->Body.="Description: $descrip\n";
+            $mail->Body.="Telephone number: $telno\n";
             $mail->Body.="Host Name: $hname\n";
             $mail->Body.="MAC Address: $macaddr\n\n";
 
