@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -26,12 +26,10 @@ require_once("../auth.php");
 
 require_once("../class.templib.php");
 
-if (!ANONYMOUS) {
-   $auth = new SQLAuthenticator(REALM, REALMERROR);
+$auth = new SQLAuthenticator(REALM, REALMERROR);
 
-   // And now perform the authentication
-   $grps=$auth->authenticate();
-}
+// And now perform the authentication
+$grps=$auth->authenticate();
 
 // set language
 isset($_COOKIE["ipplanLanguage"]) && myLanguage($_COOKIE['ipplanLanguage']);
@@ -199,24 +197,11 @@ insert($con,selectbox(array("0"=>my_("Any"),
                  array("name"=>"month")));
 
 insert($con,text(my_("Year")));
-insert($con,selectbox(array("0"=>my_("Any"),
-                           "1995"=>"1995",
-                           "1996"=>"1996",
-                           "1997"=>"1997",
-                           "1998"=>"1998",
-                           "1999"=>"1999",
-                           "2000"=>"2000",
-                           "2001"=>"2001",
-                           "2002"=>"2002",
-                           "2003"=>"2003",
-                           "2004"=>"2004",
-                           "2005"=>"2005",
-                           "2006"=>"2006",
-                           "2007"=>"2007",
-                           "2008"=>"2008",
-                           "2009"=>"2009",
-                           "2010"=>"2010"),
-                 array("name"=>"year")));
+$years=array("0"=>my_("Any"));
+$i = 1994;
+while ($i < date('Y')+15) $years[$i++] = $i;
+
+insert($con,selectbox($years, array("name"=>"year")));
 
 if (DBF_TYPE=="mysql" or DBF_TYPE=="maxsql" or DBF_TYPE=="postgres7")
    insert($con,textbrbr(my_("Search criteria (only display records matching the regular expression)")));
