@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.86a
+// IPplan v4.91a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,8 @@ require_once("../class.templib.php");
 
 // function to generate swip entry - returns a string with swip
 // which can then be displayed/emailed etc
-function genSWIP($ds, $baseindex, $start, $end, $cust, $descrip, $filename) {
+function genSWIP($ds, $baseindex, $start, $end, $cust, 
+                 $descrip, $swipmod, $filename) {
 
     global $ntnameopt;
 
@@ -98,6 +99,7 @@ function genSWIP($ds, $baseindex, $start, $end, $cust, $descrip, $filename) {
     $now = getdate();
     $fields["date"] = $now["year"] . str_pad($now["mon"], 2, '0',
             STR_PAD_LEFT) . str_pad( $now["mday"], 2, '0', STR_PAD_LEFT);
+    $fields["swipmod"]=$swipmod;
 
     //************ now process customer template fields ************//
 
